summary method for objects of class eivlm.Computes summary quantities for a model of class eivlm. The
computations include some quantities for the standard regression model
(uncorrected for covariate measurement error), as well as quantities
relevant to the EIV model.
# S3 method for eivlm
summary(object, correlation = FALSE, symbolic.cor = FALSE, ...)A model object of class eivlm.
See help for summary.lm
An list object of class summary.eivlm with components:
See eivreg.
See summary.lm.
If reliability is specified in model fit.
If Sigma_error is specified in model fit.
If symbolic.cor is specified in call to
function.
Maximum likelihood estimate of R-squared for regression of Y on (X,Z). NOTE: This is not the R-squared of the fitted regression of Y on (W,Z).
Estimate of R-squared for regression of Y on (X,Z) adjusted by number of estimated regression parameters.
The object also includes components
unadj_residuals, unadj_coefficients,
unadj_sigma, unadj_r.squared,
unadj_adj.r.squared, unadj_fstatistic and
unadj_cov.unscaled that are computed from the "unadjusted"
regression model that ignores measurement error; see
summary.lm. Also, additional components will be
included if either weights or cluster_varname is
specified in the call to eivlm; see that help file for
details.
The model fitting function eivreg, summary.
Function coef will extract the matrix of coefficients
with standard errors, t-statistics and p-values.